\name{MP.pseudoinv}
\alias{MP.pseudoinv}
\title{
   Work Function for 'smoothSurvReg', currently nowhere used.
}
\description{
   Function to compute a Moore-Penrose pseudoinverse
   of a symmetric matrix using eigen values decomposition.
}
\usage{
MP.pseudoinv(x, toler = 1e-7)
}
\arguments{
   \item{x}{
      A symmetric matrix (it is not checked).
   }
   \item{toler}{
      Under the eigen values decomposition is computed, all
      eigen values smaller in absolute value than \code{toler}
      are assumed to be zero.
   }
}
\value{
   A matrix with the Moore-Penrose pseudoinverse of \code{x}.
}
\note{
WARNING: This function was primarily used inside \code{\link{smoothSurvReg}}.
Consequently, it has very few error checks on its input arguments.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{utilities}
\eof
\name{a.to.c}
\alias{a.to.c}
\title{
   Work Function for 'smoothSurvReg'
}
\description{
   Compute the 'c' G-spline coefficients from 'a' G-spline coefficients.
}
\usage{
a.to.c(acoef)
}
\arguments{
   \item{acoef}{
       A vector of 'a' G-spline coefficients.
   }
}
\details{
   'c' and 'a' G-spline coefficients are related by the expression
   \deqn{c_j = \frac{\exp(a_j)}{\sum_{l=1}^{g}\exp(a_l)}, j = 1,\dots, g,}{%
         c[j] = exp(a[j])/[exp(a[1]) + ... + exp(a[g])], j = 1, ..., g,}
   where \eqn{a_k = 0,}{a[k] = 0,} k = \code{which.zero}.
   This function transforms the 'c' coefficients into their 'a' counterparts.

}
\value{
   A vector of same length as \code{acoef} with 'c' G-spline coefficients.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\seealso{\code{\link{c.to.a}}}
\examples{
ccoef <- c(0.1, 0.2, 0.15, 0.3, 0.25)

### Compute 'a' counterparts
acoef <- c.to.a(ccoef, 1)
print(acoef)

### And back 'c', ccoef2 should be same as ccoef
ccoef2 <- a.to.c(acoef)
print(ccoef2)
}
\keyword{utilities}
\eof
\name{c.to.a}
\alias{c.to.a}
\title{
   Work Function for 'smoothSurvReg'
}
\description{
   Compute the 'a' G-spline coefficients from 'c' G-spline coefficients.
}
\usage{
c.to.a(ccoef, which.zero = which.max(ccoef), toler = 1e-6)
}
\arguments{
   \item{ccoef}{
       A vector of 'c' G-spline coefficients.
   }
   \item{which.zero}{
       An index of the 'a' G-spline coefficient which will be zero (the reference one).
   }
   \item{toler}{
       All 'c' coefficients smaller in absolute value than \code{toler}
       are changed into \code{toler} (to avoid \code{log(0)}).
   }
}
\details{
   'c' and 'a' G-spline coefficients are related by the expression
   \deqn{c_j = \frac{\exp(a_j)}{\sum_{l=1}^{g}\exp(a_l)}, j = 1,\dots, g,}{%
         c[j] = exp(a[j])/[exp(a[1]) + ... + exp(a[g])], j = 1, ..., g,}
   where \eqn{a_k = 0,}{a[k] = 0,} k = \code{which.zero}.
   This function transforms the 'c' coefficients into their 'a' counterparts.

}
\value{
   A vector of same length as \code{ccoef} with 'a' G-spline coefficients.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\seealso{\code{\link{a.to.c}}}
\examples{
ccoef <- c(0.1, 0.2, 0.15, 0.3, 0.25)

### Compute 'a' counterparts
acoef <- c.to.a(ccoef, 1)
print(acoef)

### And back 'c', ccoef2 should be same as ccoef
ccoef2 <- a.to.c(acoef)
print(ccoef2)
}
\keyword{utilities}
\eof
\name{derivative.cc3}
\alias{derivative.cc3}
\title{
   Work Function for 'smoothSurvReg', currently nowhere used
}
\description{
   Function to compute derivatives of all 'c' G-spline coefficients
   with respect to chosen (g - 3) coefficients such that
   the whole vector of g 'c' coefficients satisfies the constraints.
}
\usage{
derivative.cc3(knots, sdspline, last.three, all = TRUE)
}
\arguments{
   \item{knots}{
      A vector of G-spline knots \eqn{\mu}{mu}.
   }
   \item{sdspline}{
      Standard deviation \eqn{sigma_0}{sigma0} of the basis G-spline .
   }
   \item{last.three}{
      Indeces of the three 'c' G-spline coefficients which are
      expressed as a function of the remaining (g - 3)
      'c' G-spline coefficients such that the three constraints
      are satisfied.
      This must be a vector of length 3 with three different numbers from
      \code{1:length(knots)}.
   }
   \item{all}{
      If \code{TRUE}, matrix (g - 2) x g (there is one zero column) is returned.
      If \code{FALSE}, matrix (g - 2) x 3 is returned.
      The first row is always an intercept.
      See details.
   }
}
\details{
   To satisfy the three constraints
   \deqn{\sum_{j=1}^g c_j = 1,}{c[1] + ... c[g] = 1,}
   \deqn{\sum_{j=1}^g c_j \mu_j = 0,}{c[1]mu[1] + ... c[g]mu[g] = 0,}
   \deqn{\sum_{j=1}^g c_j \mu_j^2 = 1 - \sigma_0^2}{c[1]mu[1]^2 + ... c[g]mu[g]^2 = 1 - sigma0^2}
   imposed on the G-spline we can express the three 'c' coefficients as a function of
   the remaining \eqn{g - 3}{g - 3} 'c' coefficients in the following way.
   \deqn{c_{k} = \omega_{0,k} + \sum_{j\neq last.three}\omega_{j,k} c_j, %
         \qquad k \in last.three,}{%
         c[k] = omega[0,k] + sum[j != last.three]omega[j,k] c[j],   %
         k = last.three[1], last.three[2], last.three[3],}
    where \eqn{\omega}{omega} coefficients are a function of knots and G-spline
    standard deviation.
    If we denote \eqn{d}{d} the vector \code{c[-last.three]} this function computes
    derivatives of \eqn{c}{c} w.r.t. \eqn{d}{d} together
    with the intercept term used to compute \eqn{c}{c} from
    \eqn{d}{d}. This is actually a matrix of \eqn{\omega}{omega}
    coefficients. If we denote it as \eqn{\Omega}{Omega} then
    if \code{all == TRUE}
    \deqn{c = \Omega_{1,\cdot}^T +  \Omega_{-1,\cdot}^T d}{%
          c = t(Omega_[1,]) +  t(Omega[-1,]) d}
    and if \code{all == FALSE}
    \deqn{c[last.three] = \Omega_{1,\cdot}^T +  \Omega_{-1,\cdot}^T d.}{%
          c[last.three] = t(Omega_[1,]) +  t(Omega[-1,]) d.}
}
\value{
   A matrix with \eqn{\omega}{omega} coefficients.
}
\note{
WARNING: This function was primarily used inside \code{\link{smoothSurvReg}}.
Consequently, it has very few error checks on its input arguments.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{utilities}
\eof
\name{derivative.expAD}
\alias{derivative.expAD}
\title{
   Work Function for 'smoothSurvReg', currently nowhere used
}
\description{
   Function to compute derivatives of exp(a) w.r.t. exp(d)
   where d stands for a shorter vector of 'a' G-spline coefficients.
}
\usage{
derivative.expAD(knots, sdspline, last.three, all = TRUE)
}
\arguments{
   \item{knots}{
      A vector of G-spline knots \eqn{\mu}{mu}.
   }
   \item{sdspline}{
      Standard deviation \eqn{\sigma_0}{sigma0} of the basis G-spline.
   }
   \item{last.three}{
      Indeces of the three 'a' G-spline coefficients which are
      expressed as a function of the remaining (g-3)
      'a' G-spline coefficients such that the three constraints
      are satisfied.
      This must be a vector of length 3 with three different numbers from
      \code{1:length(mu)}.
      Consequently, \code{a[last.three[1]] <- 0}.
   }
   \item{all}{
      If \code{TRUE}, matrix (g - 2) x g (there is one zero column) is returned.
      If \code{FALSE}, matrix (g - 2) x 2 is returned.
      The first row is always an intercept.
      See details.
   }
}
\details{
   To satisfy the three constraints
   \deqn{\sum_{j=1}^g c_j = 1,}{c[1] + ... c[g] = 1,}
   \deqn{\sum_{j=1}^g c_j \mu_j = 0,}{c[1]mu[1] + ... c[g]mu[g] = 0,}
   \deqn{\sum_{j=1}^g c_j \mu_j^2 = 1 - \sigma_0^2}{c[1]mu[1]^2 + ... c[g]mu[g]^2 = 1 - sigma0^2}
   imposed on the G-spline we use the following parametrization:
   \deqn{c_j = \frac{\exp(a_j)}{\sum_{l=1}^{g}\exp(a_l)}, j = 1,\dots, g.}{%
         c[j] = exp(a[j])/[exp(a[1]) + ... + exp(a[g])], j = 1, ..., g.}
   The constraints can be solved such that \code{a[last.three[1]] = 0} and
   \code{a[last.three[2:3]]} are expressed as a function of
   \code{a[-last.three]} in the following way:
   \deqn{a_{k} = \log\Bigl\{\omega_{0,k} + \sum_{j\neq last.three}\omega_{j,k}\exp(a_j)\Bigr\},%
         \qquad k = last.three[2], last.three[3],}{%
         a[k] = log[omega[0,k] + sum[j != last.three]omega[j,k]exp(a[j])],   %
         k = last.three[2], last.three[3],}
    where \eqn{\omega}{omega} coefficients are a function of knots and G-spline
    standard deviation.
    If we denote \eqn{d}{d} the vector \code{a[-last.three]} this function computes
    derivatives of \eqn{\exp(a)}{exp(a)} w.r.t. \eqn{\exp(d)}{exp(d)} together
    with the intercept term used to compute \eqn{\exp(a)}{exp(a)} from
    \eqn{\exp(d)}{exp(d)}. This is actually a matrix of \eqn{\omega}{omega}
    coefficients. If we denote it as \eqn{\Omega}{Omega} then
    if \code{all == TRUE}
    \deqn{\exp(a) = \Omega_{1,\cdot}^T +  \Omega_{-1,\cdot}^T\exp(d)}{%
          exp(a) = t(Omega_[1,]) +  t(Omega[-1,])exp(d)}
    and if \code{all == FALSE}
    \deqn{\exp(a[last.three[2:3]]) = \Omega_{1,\cdot}^T +  \Omega_{-1,\cdot}^T\exp(d).}{%
          exp(a[last.three[2:3]]) = t(Omega_[1,]) +  t(Omega[-1,])exp(d).}
}
\value{
   A matrix with \eqn{\omega}{omega} coefficients.
}
\note{
WARNING: This function is primarily used inside \code{\link{smoothSurvReg}}.
Consequently, it has very few error checks on its input arguments.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{utilities}
\eof
\name{extreme value}
\alias{dextreme}
\alias{dstextreme}
\title{
    Density of the Extreme Value Distribution of a Minimum.
}
\description{
    Density function of the extreme value distribution of a minimum
    with location \eqn{\alpha}{alpha} and scale \eqn{\beta}{beta}
    and the density of the standardized version (with zero mean and unit variance).
}
\usage{
dextreme(x, alpha=0, beta=1)
dstextreme(x)
}
\arguments{
   \item{x}{
      Vector of quantiles.
   }
   \item{alpha}{
      Vector of location parameters.
   }
   \item{beta}{
      Vector of scale parameters.
   }
}
\details{
   Extreme value distribution of a minimum with the location \eqn{\alpha}{alpha}
   and the scale \eqn{\beta}{beta} has a density
   \deqn{f(x) = \frac{1}{\beta}\exp\left[\frac{x-\alpha}{\beta}-\exp\left(\frac{x-\alpha}{\beta}\right)\right]}{%
         f(x) = (1/beta)*exp((x-alpha)/beta - exp((x-alpha)/beta))}
   the mean equal to \eqn{\alpha - \beta\;e}{alpha - beta*e}, where \eqn{e}{e} is approximately
   \eqn{0.5772}{0.5772} and the variance equal to \eqn{\beta^2\frac{\pi}{6}}{beta^2 pi^2/6}.
   Its standardized version is obtained with \eqn{\alpha = \frac{\sqrt{6}}{\pi}\;e}{alpha = (sqrt(6)/pi)*e} 
   and \eqn{\beta = \frac{\sqrt{6}}{\pi}}{beta = (sqrt(6)/pi).}
}
\value{
   The value of the density.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\examples{
dextreme(1, (sqrt(6)/pi)*0.5772, sqrt(6)/pi)
dstextreme(1)        ## approximately same result as on the previous row
}
\keyword{distribution}
\eof
\name{standardized logistic}
\alias{dstlogis}
\title{
    Density of Standardized Logistic Distribution.
}
\description{
    Density function of the logistic distribution with zero mean and unit variance.
}
\usage{
    dstlogis(x)
}
\arguments{
   \item{x}{
      Vector of quantiles.
   }
}
\details{
   \code{dstlogis(x) = dlogis(x, 0, sqrt(3)/pi)}
}
\value{
   The value of the density.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\seealso{
   \code{\link{dlogis}} for the logistic distribution.
}
\examples{
dstlogis(0)
dstlogis(seq(-3, 3, 0.2))
}
\keyword{distribution}
\eof
\name{find.c}
\alias{find.c}
\title{
   Work Function for 'smoothSurvReg'
}
\description{
       Find mixture proportions that approximate
       given distribution by a G-spline mixture.
}
\usage{
find.c(knots, sdspline, dist = "dnorm")
}
\arguments{
   \item{knots}{
      A vector of G-spline knots \eqn{\mu}{mu}.
   }
   \item{sdspline}{
      Standard deviation \eqn{\sigma_0}{sigma0} of the basis G-spline.
   }
   \item{dist}{
      A character string specifying the function used to compute
      a density of the distribution
      you want to approximate.
   }
}
\details{
   The function finds the G-spline coefficients that approximates
   a density given by \code{dist} in such sense that the value
   of the G-spline is exactly equal to the value of that density
   in \code{knots}.
}
\value{
   Either the vector of G-spline 'c' coefficients or \code{NULL}
   if there are problems to find them.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\examples{
knots <- seq(-4, 4, 0.5)
sd0 <- 0.3
ccoef <- find.c(knots, sd0, dist = "dstlogis")

### We plot the approximation together with the truth
###
grid <- seq(-4, 4, 0.05)
truth <- dstlogis(grid)

### Following lines compute the values of the approximation
grid.big <- matrix(grid, nrow = length(grid), ncol = length(knots))
knots.big <- matrix(knots, nrow = length(grid), ncol = length(knots), byrow = TRUE)
normals <- dnorm(grid.big, mean = knots.big, sd = sd0)
approx <- normals \%*\% ccoef

### Plot it
plot(grid, approx, type = "l", xlab = "y", ylab = "f(y)", bty = "n")
lines(grid, truth, lty = 2)
legend(-4, 0.35, c("approx", "truth"), lty = 1:2, bty = "n")
}
\keyword{utilities}
\eof
\name{give.c}
\alias{give.c}
\title{
   Work Function for 'smoothSurvReg'
}
\description{
       Give a vector of all 'c' G-spline coefficients 
       satisfying the three constrains (see below)
       if only (g-3) c's are given.
}
\usage{
give.c(knots, sdspline, last.three, c.rest)
}
\arguments{
   \item{knots}{
      A vector of G-spline knots \eqn{\mu}{mu}.
   }
   \item{sdspline}{
      Standard deviation \eqn{\sigma_0}{sigma0} of the basis G-spline.
   }
   \item{last.three}{
      Indeces of the three 'c' G-spline coefficients which are 
      not included in \code{c.rest}. This must be a vector
      of length 3 with three different numbers from
      \code{1:length(knots)}.
   }
   \item{c.rest}{
      A vector of \code{\length(knots) - 3} 'c' spline coefficients
      corresponding to knots \code{knots[-last.three]}. 
      They must all lie between zero and one and their sum must be lower 
      or equal to one.
   }
}
\details{
   The functions computes remaining three 'c' G-spline coefficients
   (if it is possible) such that the resulting G-spline satisfies
   the following:
   \deqn{\sum_{j=1}^g c_j = 1,}{c[1] + ... c[g] = 1,}
   \deqn{\sum_{j=1}^g c_j \mu_j = 0,}{c[1]mu[1] + ... c[g]mu[g] = 0,}
   \deqn{\sum_{j=1}^g c_j \mu_j^2 = 1 - \sigma_0^2.}{c[1]mu[1]^2 + ... c[g]mu[g]^2 = 1 - sigma0^2.}
}
\value{
   A vector of all \code{length(knots)} 'c' G-spline coefficients.
}
\note{
WARNING: This function is primarily used inside \code{\link{smoothSurvReg}}.
Consequently, it has very few error checks on its input arguments.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\examples{
knots <- seq(-4, 4, 0.5)
sd0 <- 0.3
ccoef <- find.c(knots, sd0, dist = "dstlogis")

last.three <- c(3, 7, 10)
c.rest <- ccoef[-last.three]
ccoef2 <- give.c(knots, sd0, last.three, c.rest)

print(ccoef)
print(ccoef2)    ## Almost no change
}
\keyword{utilities}
\eof
\name{piece}
\alias{piece}
\title{
    Left Continuous Piecewise Constant Function with a Finite Support.
}
\description{
    Function to evaluate a left continuous piecewise constant function with a finite support.
}
\usage{
    piece(x, breaks, values)
}
\arguments{
   \item{x}{
      Vector of values where the piecewise constant function should be evaluated.
   }
   \item{breaks}{
      Vector of sorted breakpoints of the piecewise constant function.
   }
   \item{values}{
      Values of the piecewise constant function. It takes the value
      \code{value[i]} on the interval \code{(breaks[i], breaks[i+1]]}. 
      The function is assumed to be zero outside its range specified
      as \code{(breaks[1], breaks[length(breaks)]]}.
      The length of the vector \code{values} must be equal to
      \code{length(breaks) - 1}
   }
}
\value{
   The value of the piecewise constant function.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\examples{
my.breaks <- c(-2, 1.5, 4, 7)
my.values <- c(0.5, 0.9, -2)
grid <- seq(-3, 8, by = 0.25)
piece(grid, my.breaks, my.values)
}
\keyword{utilities}
\eof
\name{plot.smoothSurvReg}
\alias{plot.smoothSurvReg}
\title{
   Plot Objects of Class 'smoothSurvReg'
}
\description{
   Plot the fitted error distribution.
}
\usage{
plot.smoothSurvReg(x, plot = TRUE, resid = TRUE, knots = TRUE,
   compare = TRUE, components = FALSE, standard = TRUE,
   by = NULL, toler.c = 1e-5,
   xlim = NULL, ylim = NULL,
   xlab = expression(epsilon), ylab = expression(paste("f(",epsilon,")", sep = "")),
   type = "l", lty = 1, main = NULL, sub = NULL, bty = "n", \dots)
}
\arguments{
   \item{x}{
      Object of class smoothSurvReg.
   }
   \item{plot}{
      If \code{TRUE} the plot is directly produced, otherwise only a \code{data.frame}
      with information used for later plotting is returned.
   }
   \item{resid}{
      If \code{resid & plot} residuals are added
      to the plot in the following way. Residuals based on exact observations
      are plotted by \code{pch = 3} (+), residuals based on right censored
      observations using \code{pch = 4} (x), residuals based on left censored
      observations using \code{pch = 2} (traingle) and midpoints of
      residuals based on interval censored observations using
      \code{pch = 5} (diamond).
   }
   \item{knots}{
      If \code{knots & plot} bullets indicating (transformed)
      knots corresponding to 'c' G-spline coefficients higher than \code{toler.c}
      are added to the x-axis of the plot.
   }
   \item{compare}{
      If \code{compare & !components & standard & plot} plots of the three
      parametric distributions (st. normal, st. logistic and st. minimum extreme value)
      are added to the plot for comparison.
   }
   \item{components}{
      If \code{components & standard & plot} dashed lines with weighted
      G-spline components are added to the plot.
   }
   \item{standard}{
      If \code{standard} data for plotting the fitted error distribution
      are created, otherwise data for plotting the distribution
      of \eqn{\alpha + \sigma\varepsilon}{alpha + sigma*epsilon} are created.
   }
   \item{by}{
      Step for a ploting grid. If \code{NULL} it is automatically computed.
   }
   \item{toler.c}{
      Tolerance to indicate zero 'c' G-spline coefficients used if \code{knots == TRUE}.
   }
   \item{xlim, ylim}{
      Arguments passed to the \code{\link{plot}} function.
   }
   \item{xlab, ylab}{
      Arguments passed to the \code{\link{plot}} function.
   }
   \item{type, lty}{
      Arguments passed to the \code{\link{plot}} function.
   }
   \item{main, sub}{
      Arguments passed to the \code{\link{plot}} function.
   }
   \item{bty}{
      Argument passed to the \code{\link{plot}} function.
   }
   \item{\dots}{
      Arguments passed to the \code{\link{plot}} function.
   }
}
\value{
   A dataframe with columns named \code{x} and \code{y} where \code{x} gives the grid
   and \code{y} the values of the density at that grid.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\seealso{
   \code{\link{smoothSurvReg}}, \code{\link{plot}}
}
\keyword{methods}
\eof
\name{print.smoothSurvReg}
\alias{print.smoothSurvReg}
\alias{summary.smoothSurvReg}
\title{
   Summary and Print for Objects of Class 'smoothSurvReg'
}
\description{
   Print a summary information of the fitted model.
}
\usage{
print.smoothSurvReg(x, spline = NULL, digits = min(options()$digits, 4), \dots)
summary.smoothSurvReg(object, spline = NULL, digits = min(options()$digits, 4), \dots)
}
\arguments{
   \item{x, object}{
      Object of class smoothSurvReg.
   }
   \item{spline}{
      TRUE/FALSE. If TRUE an information on fitted G-spline is printed.
   }
   \item{digits}{
      Controls the number of digits to print when printing numeric
      values.  It is a suggestion only.  Valid values are 1...22.
   }
   \item{\dots}{
      Further arguments passed to or from other methods.
   }
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\seealso{
   \code{\link{smoothSurvReg}}, \code{\link{print}}, \code{\link{summary}}
}
\keyword{methods}
\eof
\name{residuals.smoothSurvReg}
\alias{residuals.smoothSurvReg}
\title{
   Residuals for Objects of Class 'smoothSurvReg'
}
\description{
   Compute residuals for the fitted model.
}
\usage{
residuals.smoothSurvReg(object, ...)
}
\arguments{
   \item{object}{
      Object of class smoothSurvReg.
   }
   \item{\dots}{
      Argument included in the function parameters for the compatibility 
      with the generic function.
   }
}
\value{
   A dataframe with columns named \code{res}, \code{res2} and \code{censor}
   where the column \code{res2} is included only if there are any interval censored
   observations. Column \code{res} contains all residuals, column \code{res2}
   is applicable only for interval censored observations. Column \code{censor}
   gives the type of censoring (0 for right censoring, 1 for exact observations,
   2 for left censoring and 3 for interval censoring).
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\seealso{
   \code{\link{smoothSurvReg}}
}
\keyword{methods}
\eof
\name{smoothSurvReg}
\alias{smoothSurvReg}
\title{
   Regression for a Survival Model with Smoothed Error Distribution
}
\description{
   Regression for a survival model. These are all
   time-transformed location models, with the most useful case being the
   accelerated failure models that use a log transformation.
   Error distribution is assumed to be a mixture of G-splines.
   Parameters are estimated by the penalized maximum likelihood
   method.
}
\usage{
smoothSurvReg(formula = formula(data), data = parent.frame(), subset, na.action,
   init.beta = NULL, init.scale = NULL, init.c = NULL, init.dist = "best",
   update.init = TRUE, aic = TRUE, lambda = exp(2:(-9)),
   model = FALSE, control = smoothSurvReg.control(), \dots)
}
\arguments{
   \item{formula}{
      A formula expression as for other regression models.
      See the documentation for \code{\link{lm}} and \code{\link{formula}} for details.
      Use \code{\link{Surv}} on the left hand side of the formula.
   }
   \item{data}{
      Optional data frame in which to interpret the variables occurring in the
      formula.
   }
   \item{subset}{
      Subset of the observations to be used in the fit.
   }
   \item{na.action}{
      Function to be used to handle any NAs in the data.
   }
   \item{init.beta}{
      Optional vector of the initial values of the regression parameter \eqn{\beta}{beta}
      (intercept and regression itself).
   }
   \item{init.scale}{
      Optional value of the initial value of the scale parameter \eqn{\sigma}{sigma}.
   }
   \item{init.c}{
      Optional vector of the initial values for the G-spline
      coefficients c, all values must lie between 0 and 1
      and must sum up to 1.
   }
   \item{init.dist}{
      A character string specifying the distribution used by \code{\link{survreg}}
      to find the initial values for parameters (if not given by the user).
      It is assumed to name \code{"best"} or an
      element from \code{\link{survreg.distributions}}. These include
      \code{"weibull"}, \code{"exponential"}, \code{"gaussian"},
      \code{"logistic"}, \code{"lognormal"} and \code{"loglogistic"}.
      If "best" is specified one of \code{"lognormal"},
      \code{"weibull"} and \code{"loglogistic"} giving the highest
      likelihood is used.
   }
   \item{update.init}{
      If TRUE, the initial values are updated during the grid search for the lambda
      parameter giving the optimal AIC. Otherwise, fits with all lambdas during the
      grid search start with same initials determine at the beginning either
      from the values of \code{init.beta, init.scale, init.c} or from the initial
      \code{\link{survreg}} fit as determined by the parameter
      \code{init.dist}.
   }
   \item{aic}{
      If TRUE the optimal value of the tuning parameter \eqn{\lambda}{lambda}
      is determined via a grid search through the values specified
      by the parameter \code{lambda}. If FALSE, only the model with
      \eqn{\lambda = }{lambda = } \code{lambda[1]} is fitted.
   }
   \item{lambda}{
      A grid of values of the tuning parameter \eqn{\lambda}{lambda} searched
      for the optimal value if \code{aic} = TRUE.
   }
   \item{model}{
      If TRUE, the model frame is returned.
   }
   \item{control}{
      A list of control values, in the format producted by \code{\link{smoothSurvReg.control}}.
   }
   \item{...}{
      Other arguments which will be passed to \code{\link{smoothSurvReg.control}}. See its help
      page for more options to control the fit and for the possibility to fix some values
      and not to estimate them.
   }
}
\details{
   Read the paper paper.pdf found in /inst/doc directory of this library.

   There is a slight difference in the definition of the penalty used by the R function compared
   to what is written in the paper.
   The penalized log-likelihood given in the paper has a form
   \deqn{\ell_P(\theta) = \ell(\theta) - \frac{\lambda}{2}\sum_{j=m+1}^g(\Delta^m a_j)^2,}{%
        l_P(theta) = l(theta) - (lambda/2) * sum[j in (m+1):g] (Delta^m a[j])^2,}
   while the penalized log-likelihood used in the R function multiplies the tuning parameter
   \eqn{\lambda}{lambda} given by \code{lambda} by a sample size \eqn{n}{n} to keep default values
   more or less useful for samples of different sizes. So that the penalized log-likelihood
   which is maximized by the R function has the form
   \deqn{\ell_P(\theta) = \ell(\theta) - \frac{\lambda\cdot n}{2}\sum_{j=m+1}^g(\Delta^m a_j)^2.}{%
        l_P(theta) = l(theta) - ((lambda*n)/2) * sum[j in (m+1):g] (Delta^m a[j])^2.}
}
\value{
   An object of class \code{smoothSurvReg} is returned.
   See \code{\link{smoothSurvReg.object}} for details.
}
\references{
  \eqn{\mbox{Kom\'arek, A., Lesaffre, E., and Hilton, J. F. (2004)}}{Komarek, A., Lesaffre, E., and Hilton, J. F. (2004)}
  Accelerated Failure Time Model for Arbitrarily censored Data
  with Smoothed Error Distribution.
  \emph{?????}, \bold{??}, ???--???.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\examples{
### We generate interval censored data and fit a model with few artificial covariates
x1 <- rbinom(50, 1, 0.4)                                         ## binary covariate
x2 <- rnorm(50, 180, 10)                                         ## continuous covariate
y1 <- 0.5*x1 - 0.01*x2 + 0.005 *x1*x2 + 1.5*rnorm(50, 0, 1)      ## generate log(T), left limit
t1 <- exp(y1)                                                    ## left limit of the survival time
t2 <- t1 + rgamma(50, 1, 1)                                      ## right limit of the survival time
surv <- Surv(t1, t2, type = "interval2")                         ## survival object

## Fit the model with an interaction
fit1 <- smoothSurvReg(surv ~ x1 * x2, info = FALSE, lambda = exp(2:(-1)))

## Print the summary information
summary(fit1, spline = TRUE)

## Plot the fitted error distribution
plot(fit1)

## Plot the fitted error distribution with its components
plot(fit1, components = TRUE)

## Plot the cumulative distribution function corresponding to the error density
survfit(fit1, cdf = TRUE)

## Plot survivor curves for persons with (x1, x2) = (0, 180) and (1, 180)
survfit(fit1, matrix(c(0, 1, 180, 180, 0, 180), ncol = 3))

## More involved examples can be found in script files
## used to perform analyses  and draw pictures 
## presented in /inst/doc/paper.pdf of this library.
## These script files together with data for Signal Tandmobiel
## example (section 6.1 of paper.pdf) can be obtained from
## arnost.komarek@med.kuleuven.ac.be
}
\keyword{survival}
\keyword{smooth}
\eof
\name{smoothSurvReg.control}
\alias{smoothSurvReg.control}
\title{
   More Options for 'smoothSurvReg'
}
\description{
   This function checks and sets the fitting options for smoothSurvReg.
   Its arguments can be used instead of \dots in a call to smoothSurvReg.
}
\usage{
smoothSurvReg.control(est.c = TRUE, est.scale = TRUE,
   maxiter = 200, firstiter = 0, rel.tolerance = 5e-5, toler.chol = 1e-15, toler.eigen = 1e-3,
   maxhalf = 10, debug = 0, info = TRUE, lambda.use = 1.0, sdspline = NULL,
   difforder = 3, dist.range = c(-6, 6), by.knots = 0.3, knots = NULL, nsplines = NULL, last.three = NULL)
}
\arguments{
   \item{est.c}{
       If TRUE the G-spline coefficients are estimated. Otherwise, they are fixed
       to the values given by \code{init.c} parameter of \code{\link{smoothSurvReg}}.
   }
   \item{est.scale}{
       If TRUE the scale parameter \eqn{\sigma}{sigma} is estimated. Otherwise,
       it is fixed to the value given by \code{init.scale} parameter
       of \code{\link{smoothSurvReg}}.
   }
   \item{maxiter}{
       Maximum number of Newton-Raphson iterations.
   }
   \item{firstiter}{
       The index of the first iteration. This option comes from older versions
       of this function.
   }
   \item{rel.tolerance}{
       (Relative) tolerance to declare the convergence. In this version of the function,
       the convergence is declared if the relative difference between two consecutive values
       of the penalized log-likelihood are smaller than rel.tolerance.
   }
   \item{toler.chol}{
       Tolerance to declare Cholesky decomposition singular.
   }
   \item{toler.eigen}{
       Tolerance to declare an eigen value of a matrix to be zero.
   }
   \item{maxhalf}{
       Maximum number of step-halving steps if updated estimate leads to a decrease
       of the objective function.
   }
   \item{debug}{
       If non-zero print debugging information.
   }
   \item{info}{
       If TRUE information concerning the iteration process is printed
       during the computation to the standard output.
   }
   \item{lambda.use}{
       The value of the tuning (penalty) parameter \eqn{\lambda}{\lambda} used 
       in a current fit by the \code{smoothSurvReg.fit} function.
       Value of this option is not interesting for the user. The parameter
       \code{lambda} of the function \code{smoothSurvReg} is more important for 
       the user.
   }
   \item{sdspline}{
       Standard deviation of the basis G-spline. If not given it is determined
       as 2/3 times the maximal distance between the two knots. If \code{est.c} = TRUE
       and \code{sdspline} >= 1 it is changed to 0.9 to be able to satisfy the constraints
       imposed to the fitted error distribution.
   }
   \item{difforder}{
       The order of the finite difference used in the penalty term.
   }
   \item{dist.range}{
       Approximate minimal and maximal knot. If not given by \code{knots} the knots
       are determined as \code{c(seq(0, dist.range[2], by = by.knots), seq(0, dist.range[1], by = -by.knots))}.
       The sequence of knots is sorted and multiple entries are removed.
   }
   \item{by.knots}{
       The distance between the two knots used when building a vector of knots if these
       are not given by \code{knots}. This option is ignored if \code{nsplines} is not \code{NULL}.
   }
   \item{knots}{
       A vector of knots.
   }
   \item{nsplines}{
       This option is ignored at this moment. It is used to give the number of G-splines
       to the function \code{\link{smoothSurvReg.fit}}.
   }
   \item{last.three}{
       A vector of length 3 with indeces of reference knots. The 'a' coefficient of
       the \code{knot[last.three[1]]} is then equal to zero, 'a' coefficients
       with indeces \code{last.three[2:3]} are expressed as a function of remaining
       'a' coefficients such that resulting error distribution has zero mean and unit
       variance. If \code{maxiter > 0} \code{last.three} is determined after
       the convergence is reached. If \code{maxiter == 0} \code{last.three} is used 
       to compute variance matrices.
   }
}
\value{
   A list with the same elements as the input except \code{dist.range} and \code{by.knots}
   is returned.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{survival}
\keyword{smooth}
\eof
\name{smoothSurvReg.fit}
\alias{smoothSurvReg.fit}
\title{
   Work Function to Fit the Model Using 'smoothSurvReg'
}
\description{
   Fit the survival regression model with smoothed error distribution.
   This function is not to be called by the user.
}
\usage{
smoothSurvReg.fit(x, y, offset = NULL, correctlik, init, controlvals)
}
\arguments{
   \item{x}{
       A covariate matrix.
   }
   \item{y}{
       A two- or three- column matrix with response. The last column
       indicate the type of censoring. See \code{\link{Surv}} for details.
   }
   \item{offset}{
       A vector with possible offset term.
   }
   \item{correctlik}{
       Correction term to the likelihood due to the log transformation of the response.
   }
   \item{init}{
       A list with components \code{beta}, \code{scale}, \code{ccoef}
       giving the initial values for the fitting process.
   }
   \item{controlvals}{
       A list returned by \code{\link{smoothSurvReg.control}}.
   }
}
\value{
   A list with components \code{regres, spline, loglik, aic, degree.smooth, var, var2,
   iter, estimated, warning, fail, H, I, G, U}.
}
\note{
WARNING: Most users will call the higher level routine smoothSurvReg.
Consequently, this function has very few error checks on its input arguments.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{survival}
\keyword{smooth}\eof
\name{smoothSurvReg.object}
\alias{smoothSurvReg.object}
\title{
   Smoothed Survival Regression Object
}
\description{
This class of objects is returned by the \code{smoothSurvReg} class of functions to represent
a fitted smoothed survival regression model.

Objects of this class have methods for the functions \code{print}, \code{summary}, \code{plot},
\code{residuals}, \code{survfit}.
}
\section{COMPONENTS I}{
The following components must be included in a legitimate \code{smoothSurvReg} object.
\describe{
\item{fail}{
Indicator of the failure of the fitting procedure. Possible values are
0 for no problems,
3 if the iteration process was stopped because of non-positive definite minus Hessian,
4 if the eiteration process was stopped because too many halving steps were performed,
5 if it was not possible to find the three reference knots (it was not then possible
to perform optimization with respect to the full parameter vector),
6 if the maximal number of iterations was performed without reaching a convergence.
The \code{fail} component is increased by 10 if the final minus Hessian of the penalized
log-likelihood was not positive definite.
The \code{fail} component is further increased by 20 if the computed effective degrees of freedom
were non-positive.
The \code{fail} component is further increased by 40 if there are negative estimates
of standard errors for some regression parameters.
The \code{fail} component is 99 or higher if the fitting procedure failed at all and
there is no fit produced.
}
}
}
\section{COMPONENTS II}{
The following components must be included in a legitimate \code{smoothSurvReg} object
if \code{fail} is lower than 99.
\describe{
\item{regres}{
Estimates of the regression parameters \eqn{\alpha, \beta, \sigma}{alpha, beta, sigma} if
these have been estimated with their standard errors stored in a data frame
with \code{colnames} ``Value", ``Std.Error", ``Std.Error2" and \code{rownames} derived from
the names of the design matrix with ``(Intercept)" for the intercept, ``Scale" for the scale
and ``Log(scale)" for the log-scale. The two standard errors are computed using either
\code{var} or \code{var2} described below.
}
\item{spline}{
Description of the fitted error density. A data frame with \code{colnames} ``Knot", ``SD basis",
``c coef.", ``Std.Error.c", ``Std.Error2.c",
``a coef.", ``Std.Error.a" and ``Std.Error2.a"
and \code{rownames} knot[1], \dots, knot[g] where
\eqn{g}{g} stands for the number of basis G-splines. The column ``Knot" contains the knots
in ascending order, ``SD basis" the standard deviation of an appropriate basis G-spline,
``c coef." estimates of the G-spline coefficients and ``Std.Error.c" and ``Std.Error2.c" the estimates
of their standard errors based either on \code{var} or \code{var2}. 
The column ``a coef." contains the estimates of transformed \eqn{c}{c} coefficients where 
\deqn{c_j = \frac{\exp(a_j)}{\sum_{l=1}^{g}\exp(a_l)}, j = 1,\dots, g.}{%
      c[j] = exp(a[j])/[exp(a[1]) + ... + exp(a[g])], j = 1, ..., g.}
If the error distribution is estimated, one of the \eqn{a}{a} coefficients is set to zero and  
two other \eqn{a}{a}'s are expressed as a function of the remaining \eqn{a}{a} coefficients
(to avoid equality constraints concerning the mean and the variance of the error distribution). 
The standard error for these three \eqn{a}{a} coefficients is then not available (it is equal
to \code{NA}).
Standard error is set to
\code{NaN} is a diagonal element of the appropriate covariance matrix was negative.
}
\item{loglik}{
Maximized penalized log-likelihood, log-likelihood and the penalty term. A data frame with one row
and three columns named ``Log Likelihood", ``Penalty" and ``Penalized Log Likelihood".
}
\item{aic}{
Akaike's information criterion of the fitted model computed as a maximized value of the penalized
log-likelihood minus the effective degrees of freedom.
}
\item{degree.smooth}{
Effective degrees of freedom, number of parameters and related information. A data frame with one row
and columns named ``Lambda", ``Log(Lambda)", ``df", 
``Number of parameters", ``Regression param.", ``Spline param." where
``Lambda" gives the value of the tunning parameter used in the final (optimal) fit, 
``df" the effective degrees of freedom, 
``Number of parameters" the real number of parameters and 
``Regression param." with ``Spline param." its decomposition. 
Note that if G-spline coefficients are estimated ``Spline param."
is equal to the number of basis G-spline with non-zero coefficients minus three.
}
\item{var}{
The estimate of the covariance matrix of the estimates based on the Bayesian approximation.
It is equal to the inverse of the converged minus Hessian of the penalized log-likelihood.
Note that there are no columns and rows corresponding to the three transformed G-spline
coefficients since these are functions of the remaining transformed G-spline coefficients
(to avoid equality constraints).
}
\item{var2}{
The estimate of the covariance matrix of the estimates based on the asymptotic theory
for penalized models. It is equal to \eqn{H^{-1}\,I\,H^{-1}}{H^{-1} I H^{-1}} where
H is converged minus Hessian of the penalized log-likelihood and I is converged minus
Hessian of the log-likelihood component of the penalized log-likelihood.
}
\item{iter}{
Used number of iterations to fit the model with the optimal \eqn{\lambda}{lambda}.
}
\item{estimated}{
Indicator of what has really been estimated and not fixed. A two-component vector with component
names ``Scale", ``ccoef". The first component is TRUE if the scale parameter was not fixed, the second
component is TRUE is the G-spline coefficients were not fixed.
}
\item{warning}{
A data frame with one column called ``warnings" and three rows called 
``Convergence", ``Final minus Hessian" and ``df" 
containing a string information corresponding to the value of the \code{fail} component
of the object. It contains a string ``OK" if there are no problems with the appropriate part
of the fitting process.
}
\item{H}{
Converged minus Hessian of the penalized log-likelihood. 
}
\item{I}{
Converged minus Hessian of the log-likelihood component of the penalized log-likelihood.
\eqn{I = H - G}{I = H - G}.
}
\item{G}{
Converged minus Hessian of the penalty term of the penalty term of the penalized log-likelihood.
\eqn{G = H - I}{G = H - I}.
}
\item{U}{
Converged score vector based on the penalized log-likelihood.
}
\item{na.action}{
The \code{na.action} attribute, if any, that was returned by the \code{na.action} routine.
}
\item{terms}{
The \code{terms} object used.
}
\item{formula}{
A symbolic description of the model to be fit.
}
\item{call}{
The matched call.
}
\item{init.dist}{
A string indicating the error distribution of the untransformed response to find the initial values. 
Possible values are ``lognormal", ``loglogistic", ``weibull".
}
\item{model}{
If requested, the model frame used.
}
\item{x}{
The model matrix used.
}
\item{y}{
The response matrix used (two columns if there were no interval censored observations,
three columns if there were some interval censored observations). The last column
indicates the death status.
}
\item{init.spline}{
A data frame describing the initial error density. It has columns named ``Knot", ``SD basis",
``c coef." and rows named ``knot[1]", \dots, ``knot[g]".
}
\item{init.regres}{
Initial estimates of the regression parameters. A data frame with one column named ``Value"
and rows named as in the \code{regres} component of the \code{smoothSurvReg} object.
}
\item{adjust}{
Adjusted intercept and scale. A data frame with a column named ``Value" and rows named ``(Intercept)"
and ``Scale". ``(Intercept)" gives the overall intercept taking into account the mean of the fitted
error distribution, ``Scale" gives the overall scale taking into account the variance of the
fitted error distribution. If the error distribution is standardized
(always when G-spline coefficients are estimated)
then the ``(Intercept)" is equal to the ``(Intercept)" from the \code{regres} component and
``Scale" is equal to the ``Scale" of either \code{regres} or \code{init.regres} component.
}
\item{error.dist}{
A data frame with columns named ``Mean", ``Var" and ``SD" and a row named ``Error distribution:  "
giving the mean, variance and the standard deviation of the fitted error distribution.
These are equal to 0, 1 and 1 if the G-spline coefficients were estimated.
}
\item{searched}{
Information concerning the searched values of the tunning paramater \eqn{\lambda}{lambda}
when looking for the best AIC. 
A data frame with columns named ``Lambda", ``Log(Lambda)", ``AIC", ``df",
``PenalLogLik", ``LogLik", ``nOfParm", ``fail".
}
}
}
\author{
\eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\keyword{survival}
\keyword{smooth}
\eof
\name{std.data}
\alias{std.data}
\title{
   Standardization of the Data
}
\description{
   Chosen columns of a \code{data.frame} are standardized by
   using a sample mean and sample standard deviation.
}
\usage{
std.data(datain, cols)
}
\arguments{
   \item{datain}{
      Input data frame.
   }
   \item{cols}{
      A character vector with names of the columns to be standardized.
   }
}
\details{
   For each chosen column the sample mean and the sample standard deviation
   is computed and then used to standardize the column. Missing values are 
   ignored when computing the mean and the standard deviation.
}
\value{
   A \code{data.frame} with same variables as the input \code{data.frame}.
   Chosen columns are standardized.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\examples{
variable1 <- rnorm(30)
variable2 <- rbinom(30, 1, 0.4)
variable3 <- runif(30)
data.example <- data.frame(variable1, variable2, variable3)
## We standardize only the first and the third column.
data.std <- std.data(data.example, c("variable1", "variable3"))
print(data.std)
print(c(mean(data.std$variable1), sd(data.std$variable1)))
print(c(mean(data.std$variable3), sd(data.std$variable3)))
}
\keyword{manip}
\eof
\name{survfit.smoothSurvReg}
\alias{survfit.smoothSurvReg}
\title{
   Survivor Curves for Objects of Class 'smoothSurvReg'
}
\description{
   Compute and plot survivor function/cumulative distribution function
   for the fitted model.
}
\usage{
survfit.smoothSurvReg(formula, cov = NULL, plot = TRUE, cdf = FALSE, by = NULL,
   xlim = NULL, ylim = c(0, 1), xlab = "t", ylab = expression(paste("S(","t",")", sep = "")),
   type = "l", lty = NULL, main = NULL, sub = NULL, legend = NULL, bty = "n", \dots)
}
\arguments{
   \item{formula}{
      Object of class smoothSurvReg.
   }
   \item{cov}{
      Vector or matrix with covariates values for which the survivor curve/cdf
      is to be computed and plotted. It must be a matrix with as many columns as
      is the number of covariates (interactions included) or the vector of length
      equal to the number of covariates (interactions included). Intercept is not
      to be included in \code{cov}. If \code{cov == NULL} a survivor curve
      for the value of a covariate vector equal to zero is plotted. If there is
      only intercept in the model the survivor curve based on the fiiied error
      distribution is always plotted.
   }
   \item{plot}{
      If \code{TRUE} the plot is directly produced, otherwise only a \code{data.frame}
      with information used for later plotting is returned.
   }
   \item{cdf}{
     If \code{TRUE} cumulative distribution function is plotted instead of
     the survivor function.
   }
   \item{by}{
      Step for a ploting grid. If \code{NULL} it is automatically computed.
   }
   \item{xlim, ylim}{
      Arguments passed to the \code{\link{plot}} function.
   }
   \item{xlab, ylab}{
      Arguments passed to the \code{\link{plot}} function.
   }
   \item{type, lty}{
      Arguments passed to the \code{\link{plot}} function.
   }
   \item{main, sub}{
      Arguments passed to the \code{\link{plot}} function.
   }
   \item{legend, bty}{
      Argument passed to the \code{\link{plot}} function.
   }
   \item{\dots}{
      Arguments passed to the \code{\link{plot}} function.
   }
}
\value{
   A dataframe with columns named \code{x} and \code{y} where \code{x} gives the grid
   and \code{y} the values of the survivor/cum. distribution function at that grid.
}
\author{
  \eqn{\mbox{Arno\v{s}t Kom\'arek}}{Arnost Komarek} \email{arnost.komarek@med.kuleuven.ac.be}
}
\seealso{
   \code{\link{smoothSurvReg}}, \code{\link{plot}}
}
\keyword{methods}
\eof
